@@ -55,7 +55,8 @@ def cal_erle(micFile = None,testFile =None, refFile =None,targetType=0):
         mydll = ctypes.windll.LoadLibrary(sys.prefix + '/ERLE_estimation.dll')
     if cur_paltform == 'macOS':
         mydll = CDLL(sys.prefix + '/ERLE_estimation.dylib')
-
+    if cur_paltform == 'Linux':
+        mydll = CDLL(sys.prefix + '/ERLE_estimation.so')
     mydll.ERLE_estimation.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double,c_double,c_double,POINTER(c_double),POINTER(c_double),POINTER(c_double),POINTER(c_double)]
     data_format = c_double*11
     gain_table = data_format()
